==> doma-core-2.60.1.jar: module-info.java <==
module org.seasar.doma.core {
    /* transitive */ requires java.sql;
    /* transitive */ /* static phase */ requires java.compiler;

    exports org.seasar.doma;
    exports org.seasar.doma.expr;
    exports org.seasar.doma.jdbc;
    exports org.seasar.doma.jdbc.builder;
    exports org.seasar.doma.jdbc.command;
    exports org.seasar.doma.jdbc.criteria;
    exports org.seasar.doma.jdbc.criteria.command;
    exports org.seasar.doma.jdbc.criteria.context;
    exports org.seasar.doma.jdbc.criteria.declaration;
    exports org.seasar.doma.jdbc.criteria.expression;
    exports org.seasar.doma.jdbc.criteria.metamodel;
    exports org.seasar.doma.jdbc.criteria.option;
    exports org.seasar.doma.jdbc.criteria.query;
    exports org.seasar.doma.jdbc.criteria.statement;
    exports org.seasar.doma.jdbc.criteria.tuple;
    exports org.seasar.doma.jdbc.dialect;
    exports org.seasar.doma.jdbc.domain;
    exports org.seasar.doma.jdbc.entity;
    exports org.seasar.doma.jdbc.id;
    exports org.seasar.doma.jdbc.query;
    exports org.seasar.doma.jdbc.tx;
    exports org.seasar.doma.jdbc.type;
    exports org.seasar.doma.message;
    exports org.seasar.doma.wrapper;
    exports org.seasar.doma.internal;
    exports org.seasar.doma.internal.jdbc.command;
    exports org.seasar.doma.internal.jdbc.dao;
    exports org.seasar.doma.internal.jdbc.entity;
    exports org.seasar.doma.internal.jdbc.scalar;
    exports org.seasar.doma.internal.jdbc.sql;
    exports org.seasar.doma.internal.wrapper;
    exports org.seasar.doma.internal.util;
    exports org.seasar.doma.internal.expr to org.seasar.doma.processor;
    exports org.seasar.doma.internal.expr.node to org.seasar.doma.processor;
    exports org.seasar.doma.internal.jdbc.sql.node to org.seasar.doma.processor;
    exports org.seasar.doma.internal.jdbc.util to org.seasar.doma.processor;

}

==> doma-core-3.11.0.jar: module-info.java <==
module org.seasar.doma.core {
    /* transitive */ requires java.sql;
    /* transitive */ /* static phase */ requires java.compiler;

    exports org.seasar.doma;
    exports org.seasar.doma.expr;
    exports org.seasar.doma.jdbc;
    exports org.seasar.doma.jdbc.builder;
    exports org.seasar.doma.jdbc.command;
    exports org.seasar.doma.jdbc.criteria;
    exports org.seasar.doma.jdbc.criteria.command;
    exports org.seasar.doma.jdbc.criteria.context;
    exports org.seasar.doma.jdbc.criteria.declaration;
    exports org.seasar.doma.jdbc.criteria.expression;
    exports org.seasar.doma.jdbc.criteria.metamodel;
    exports org.seasar.doma.jdbc.criteria.option;
    exports org.seasar.doma.jdbc.criteria.query;
    exports org.seasar.doma.jdbc.criteria.statement;
    exports org.seasar.doma.jdbc.criteria.tuple;
    exports org.seasar.doma.jdbc.dialect;
    exports org.seasar.doma.jdbc.domain;
    exports org.seasar.doma.jdbc.entity;
    exports org.seasar.doma.jdbc.id;
    exports org.seasar.doma.jdbc.query;
    exports org.seasar.doma.jdbc.statistic;
    exports org.seasar.doma.jdbc.tx;
    exports org.seasar.doma.jdbc.type;
    exports org.seasar.doma.message;
    exports org.seasar.doma.util;
    exports org.seasar.doma.wrapper;
    exports org.seasar.doma.internal;
    exports org.seasar.doma.internal.jdbc.command;
    exports org.seasar.doma.internal.jdbc.dao;
    exports org.seasar.doma.internal.jdbc.entity;
    exports org.seasar.doma.internal.jdbc.scalar;
    exports org.seasar.doma.internal.jdbc.sql;
    exports org.seasar.doma.internal.wrapper;
    exports org.seasar.doma.internal.util;
    exports org.seasar.doma.internal.expr;
    exports org.seasar.doma.internal.expr.node;
    exports org.seasar.doma.internal.jdbc.sql.node;
    exports org.seasar.doma.internal.jdbc.util;
    exports org.seasar.doma.jdbc.aggregate;

}
